@@ -40,10 +40,10 @@ GNU General Public License for more details.
 
 void TCourse::SetDescription(const std::string& description) {
 	FT.AutoSizeN(2);
-	vector<string> desclist = FT.MakeLineList(description.c_str(), 335.f * Winsys.scale - 16.f);
-	size_t cnt = min<size_t>(desclist.size(), MAX_DESCRIPTION_LINES);
+	std::vector<std::string> desclist = FT.MakeLineList(description.c_str(), 335.f * Winsys.scale - 16.f);
+	std::size_t cnt = std::min<std::size_t>(desclist.size(), MAX_DESCRIPTION_LINES);
 	num_lines = cnt;
-	for (size_t ll = 0; ll < cnt; ll++) {
+	for (std::size_t ll = 0; ll < cnt; ll++) {
 		desc[ll] = desclist[ll];
 	}
 }
@@ -62,22 +62,23 @@ void TCourse::SetTranslatedData(const std::string& line2) {
 CCourse Course;
 
 
-CCourse::CCourse() {
-	vnc_array = nullptr;
-	mirrored = false;
-
-	curr_course = nullptr;
-	currentCourseList = nullptr;
+CCourse::CCourse()
+	: curr_course(nullptr)
+	, nx(0), ny(0)
+	, base_height_value(0)
+	, mirrored(false)
+	, currentCourseList(nullptr)
+	, vnc_array(nullptr) {
 }
 
 CCourse::~CCourse() {
-	for (std::map<std::string, CCourseList>::iterator i = CourseLists.begin(); i != CourseLists.end(); ++i)
+	for (std::unordered_map<std::string, CCourseList>::iterator i = CourseLists.begin(); i != CourseLists.end(); ++i)
 		i->second.Free();
 	ResetCourse();
 }
 
 double CCourse::GetBaseHeight(double distance) const {
-	double slope = tan(ANGLES_TO_RADIANS(curr_course->angle));
+	double slope = std::tan(ANGLES_TO_RADIANS(curr_course->angle));
 
 	return -slope * distance -
 	       base_height_value / 255.0 * curr_course->scale;
@@ -87,16 +88,16 @@ double CCourse::GetMaxHeight(double distance) const {
 	return GetBaseHeight(distance) + curr_course->scale;
 }
 
-const TPolyhedron& CCourse::GetPoly(size_t type) const {
+const TPolyhedron& CCourse::GetPoly(std::size_t type) const {
 	return PolyArr[ObjTypes[type].poly];
 }
 
-TCourse* CCourse::GetCourse(const string& group, const string& dir) {
+TCourse* CCourse::GetCourse(const std::string& group, const std::string& dir) {
 	return &CourseLists.at(group)[dir];
 }
 
-size_t CCourse::GetCourseIdx(const TCourse* course) const {
-	size_t idx = (course - &(*currentCourseList)[0]);
+std::size_t CCourse::GetCourseIdx(const TCourse* course) const {
+	std::size_t idx = (course - &(*currentCourseList)[0]);
 	if (idx >= currentCourseList->size())
 		return -1;
 	return idx;
@@ -251,9 +252,9 @@ void CCourse::FillGlArrays() {
 		for (unsigned int y = 0; y < ny; y++) {
 			int idx = STRIDE_GL_ARRAY * (y * nx + x);
 
-			FLOATVAL(0) = (GLfloat)x / (nx-1.0) * curr_course->size.x;
+			FLOATVAL(0) = (GLfloat)x / (nx-1.f) * curr_course->size.x;
 			FLOATVAL(1) = Fields[x + nx*y].elevation;
-			FLOATVAL(2) = -(GLfloat)y / (ny-1.0) * curr_course->size.y;
+			FLOATVAL(2) = -(GLfloat)y / (ny-1.f) * curr_course->size.y;
 
 			const TVector3d& nml = Fields[ x + y * nx ].nml;
 			FLOATVAL(4) = nml.x;
@@ -275,60 +276,36 @@ void CCourse::MakeStandardPolyhedrons() {
 	// polyhedron "none"
 
 	// poyhedron "tree"
-	PolyArr[1].vertices.resize(6);
-	PolyArr[1].vertices[0] = TVector3d(0, 0, 0);
-	PolyArr[1].vertices[1] = TVector3d(0, 0.15, 0.5);
-	PolyArr[1].vertices[2] = TVector3d(0.5, 0.15, 0);
-	PolyArr[1].vertices[3] = TVector3d(0, 0.15, -0.5);
-	PolyArr[1].vertices[4] = TVector3d(-0.5, 0.15, 0);
-	PolyArr[1].vertices[5] = TVector3d(0, 1, 0);
+	PolyArr[1].vertices = {
+		TVector3d(0, 0, 0),
+		TVector3d(0, 0.15, 0.5),
+		TVector3d(0.5, 0.15, 0),
+		TVector3d(0, 0.15, -0.5),
+		TVector3d(-0.5, 0.15, 0),
+		TVector3d(0, 1, 0)
+	};
 
-	PolyArr[1].polygons.resize(8);
-	for (size_t i = 0; i < 8; i++) {
-		PolyArr[1].polygons[i].vertices.resize(3);
-	}
-	PolyArr[1].polygons[0].vertices[0] = 0;
-	PolyArr[1].polygons[0].vertices[1] = 1;
-	PolyArr[1].polygons[0].vertices[2] = 4;
-
-	PolyArr[1].polygons[1].vertices[0] = 0;
-	PolyArr[1].polygons[1].vertices[1] = 2;
-	PolyArr[1].polygons[1].vertices[2] = 1;
-
-	PolyArr[1].polygons[2].vertices[0] = 0;
-	PolyArr[1].polygons[2].vertices[1] = 3;
-	PolyArr[1].polygons[2].vertices[2] = 2;
-
-	PolyArr[1].polygons[3].vertices[0] = 0;
-	PolyArr[1].polygons[3].vertices[1] = 4;
-	PolyArr[1].polygons[3].vertices[2] = 3;
-
-	PolyArr[1].polygons[4].vertices[0] = 1;
-	PolyArr[1].polygons[4].vertices[1] = 5;
-	PolyArr[1].polygons[4].vertices[2] = 4;
-
-	PolyArr[1].polygons[5].vertices[0] = 2;
-	PolyArr[1].polygons[5].vertices[1] = 5;
-	PolyArr[1].polygons[5].vertices[2] = 1;
-
-	PolyArr[1].polygons[6].vertices[0] = 3;
-	PolyArr[1].polygons[6].vertices[1] = 5;
-	PolyArr[1].polygons[6].vertices[2] = 2;
-
-	PolyArr[1].polygons[7].vertices[0] = 4;
-	PolyArr[1].polygons[7].vertices[1] = 5;
-	PolyArr[1].polygons[7].vertices[2] = 3;
+	PolyArr[1].polygons = {
+		{ { 0, 1, 4 } },
+		{ { 0, 2, 1 } },
+		{ { 0, 3, 2 } },
+		{ { 0, 4, 3 } },
+		{ { 1, 5, 4 } },
+		{ { 2, 5, 1 } },
+		{ { 3, 5, 2 } },
+		{ { 4, 5, 3 } },
+	};
 }
 
 void CCourse::FreeTerrainTextures() {
-	for (size_t i=0; i<TerrList.size(); i++) {
+	for (std::size_t i=0; i<TerrList.size(); i++) {
 		delete TerrList[i].texture;
 		TerrList[i].texture = nullptr;
 	}
 }
 
 void CCourse::FreeObjectTextures() {
-	for (size_t i=0; i<ObjTypes.size(); i++) {
+	for (std::size_t i=0; i<ObjTypes.size(); i++) {
 		delete ObjTypes[i].texture;
 		ObjTypes[i].texture = nullptr;
 	}
@@ -352,7 +329,7 @@ bool CCourse::LoadElevMap() {
 	ny = img.getSize().y;
 	Fields.resize(nx*ny);
 
-	double slope = tan(ANGLES_TO_RADIANS(curr_course->angle));
+	double slope = std::tan(ANGLES_TO_RADIANS(curr_course->angle));
 	int pad = 0;
 	int depth = 4;
 	const uint8_t* data = img.getPixelsPtr();
@@ -378,7 +355,7 @@ void CCourse::LoadItemList() {
 		return;
 	}
 
-	CSPList list(16000);
+	CSPList list;
 
 	if (!list.Load(CourseDir, "items.lst")) {
 		Message("could not load items list");
@@ -395,12 +372,11 @@ void CCourse::LoadItemList() {
 		double xx = (nx - x) / (double)((double)nx - 1.0) * curr_course->size.x;
 		double zz = -(int)(ny - z) / (double)((double)ny - 1.0) * curr_course->size.y;
 
-		string name = SPStrN(*line, "name");
-		size_t type = ObjectIndex[name];
+		std::string name = SPStrN(*line, "name");
+		std::size_t type = ObjectIndex[name];
 		if (ObjTypes[type].texture == nullptr && ObjTypes[type].drawable) {
-			string terrpath = param.obj_dir + SEP + ObjTypes[type].textureFile;
 			ObjTypes[type].texture = new TTexture();
-			ObjTypes[type].texture->Load(terrpath, false);
+			ObjTypes[type].texture->Load(MakePathStr(param.obj_dir, ObjTypes[type].textureFile), false);
 		}
 
 		if (ObjTypes[type].collidable)
@@ -408,6 +384,9 @@ void CCourse::LoadItemList() {
 		else
 			NocollArr.emplace_back(xx, FindYCoord(xx, zz), zz, height, diam, ObjTypes[type]);
 	}
+	std::sort(CollArr.begin(), CollArr.end(), [](const TCollidable& l, const TCollidable& r) -> bool {
+		return l.tree_type < r.tree_type;
+	});
 }
 
 // --------------------	LoadObjectMap ---------------------------------
@@ -419,12 +398,12 @@ static int GetObject(const unsigned char* pixel) {
 	int b = pixel[2];
 
 	if (r<150 && b>200) return 0;
-	if (abs(r-194)<10 && abs(g-40)<10 && abs(b-40)<10) return 1;
-	if (abs(r-128)<10 && abs(g-128)<10 && b<10) return 2;
+	if (std::abs(r-194)<10 && std::abs(g-40)<10 && std::abs(b-40)<10) return 1;
+	if (std::abs(r-128)<10 && std::abs(g-128)<10 && b<10) return 2;
 	if (r>220 && g>220 && b<20) return 3;
-	if (r>220 && abs(g-128)<10 && b>220) return 4;
+	if (r>220 && std::abs(g-128)<10 && b>220) return 4;
 	if (r>220 && g>220 && b>220) return 5;
-	if (r>220 && abs(g-96)<10 && b<40) return 6;
+	if (r>220 && std::abs(g-96)<10 && b<40) return 6;
 	if (r<40 && g >220 && b<80) return 7;
 	return -1;
 }
@@ -462,7 +441,7 @@ bool CCourse::LoadAndConvertObjectMap() {
 	int depth = 4;
 	const unsigned char* data = (unsigned char*)treeImg.getPixelsPtr();
 	double height, diam;
-	CSPList savelist(10000);
+	CSPList savelist;
 
 	CollArr.clear();
 	NocollArr.clear();
@@ -475,9 +454,8 @@ bool CCourse::LoadAndConvertObjectMap() {
 				double xx = (nx - x) / (double)((double)nx - 1.0) * curr_course->size.x;
 				double zz = -(int)(ny - y) / (double)((double)ny - 1.0) * curr_course->size.y;
 				if (ObjTypes[type].texture == nullptr && ObjTypes[type].drawable) {
-					string terrpath = param.obj_dir + SEP + ObjTypes[type].textureFile;
 					ObjTypes[type].texture = new TTexture();
-					ObjTypes[type].texture->Load(terrpath, false);
+					ObjTypes[type].texture->Load(MakePathStr(param.obj_dir, ObjTypes[type].textureFile), false);
 				}
 
 				// set random height and diam - see constants above
@@ -509,7 +487,7 @@ bool CCourse::LoadAndConvertObjectMap() {
 				else
 					NocollArr.emplace_back(xx, FindYCoord(xx, zz), zz, height, diam, ObjTypes[type]);
 
-				string line = "*[name]";
+				std::string line = "*[name]";
 				line += ObjTypes[type].name;
 				SPSetIntN(line, "x", x);
 				SPSetIntN(line, "z", y);
@@ -520,7 +498,7 @@ bool CCourse::LoadAndConvertObjectMap() {
 		}
 		pad += (nx * depth) % 4;
 	}
-	string itemfile = CourseDir + SEP "items.lst";
+	std::string itemfile = CourseDir + SEP "items.lst";
 	savelist.Save(itemfile);  // Convert trees.png to items.lst
 	return true;
 }
@@ -530,7 +508,7 @@ bool CCourse::LoadAndConvertObjectMap() {
 // --------------------------------------------------------------------
 
 bool CCourse::LoadObjectTypes() {
-	CSPList list(MAX_OBJECT_TYPES+10);
+	CSPList list;
 
 	if (!list.Load(param.obj_dir, "object_types.lst")) {
 		Message("could not load object types");
@@ -538,7 +516,7 @@ bool CCourse::LoadObjectTypes() {
 	}
 
 	ObjTypes.resize(list.size());
-	size_t i = 0;
+	std::size_t i = 0;
 	for (CSPList::const_iterator line = list.cbegin(); line != list.cend(); ++line, i++) {
 		ObjTypes[i].name = SPStrN(*line, "name");
 		ObjTypes[i].textureFile = ObjTypes[i].name;
@@ -548,7 +526,7 @@ bool CCourse::LoadObjectTypes() {
 		if (ObjTypes[i].drawable) {
 			ObjTypes[i].textureFile = SPStrN(*line, "texture");
 		}
-		ObjTypes[i].collectable = SPBoolN(*line, "snap", -1) != 0;
+		ObjTypes[i].collectable = SPBoolN(*line, "snap", true) != 0;
 		if (ObjTypes[i].collectable == 0) {
 			ObjTypes[i].collectable = -1;
 		}
@@ -572,10 +550,10 @@ bool CCourse::LoadObjectTypes() {
 // ====================================================================
 
 int CCourse::GetTerrain(const unsigned char* pixel) const {
-	for (size_t i=0; i<TerrList.size(); i++) {
-		if (abs(pixel[0]-TerrList[i].col.r) < 30
-		        && abs(pixel[1]-TerrList[i].col.g) < 30
-		        && abs(pixel[2]-TerrList[i].col.b) < 30) {
+	for (std::size_t i=0; i<TerrList.size(); i++) {
+		if (std::abs(pixel[0]-TerrList[i].col.r) < 30
+		        && std::abs(pixel[1]-TerrList[i].col.g) < 30
+		        && std::abs(pixel[2]-TerrList[i].col.b) < 30) {
 			return (int)i;
 		}
 	}
@@ -587,7 +565,7 @@ int CCourse::GetTerrain(const unsigned char* pixel) const {
 // --------------------------------------------------------------------
 
 bool CCourse::LoadTerrainTypes() {
-	CSPList list(MAX_TERR_TYPES +10);
+	CSPList list;
 
 	if (!list.Load(param.terr_dir, "terrains.lst")) {
 		Message("could not load terrain types");
@@ -595,14 +573,14 @@ bool CCourse::LoadTerrainTypes() {
 	}
 
 	TerrList.resize(list.size());
-	size_t i = 0;
+	std::size_t i = 0;
 	for (CSPList::const_iterator line = list.cbegin(); line != list.cend(); ++line, i++) {
 		TerrList[i].textureFile = SPStrN(*line, "texture");
 		TerrList[i].sound = Sound.GetSoundIdx(SPStrN(*line, "sound"));
 		TerrList[i].starttex = SPIntN(*line, "starttex", -1);
 		TerrList[i].tracktex = SPIntN(*line, "tracktex", -1);
 		TerrList[i].stoptex = SPIntN(*line, "stoptex", -1);
-		TerrList[i].col = SPColor3N(*line, "col", TColor3(255, 255, 255));
+		TerrList[i].col = SPColor3N(*line, "col", sf::Color::White);
 		TerrList[i].friction = SPFloatN(*line, "friction", 0.5f);
 		TerrList[i].depth = SPFloatN(*line, "depth", 0.01f);
 		TerrList[i].particles = SPBoolN(*line, "part", false);
@@ -654,38 +632,38 @@ bool CCourse::LoadTerrainMap() {
 // --------------------------------------------------------------------
 
 bool CCourseList::Load(const std::string& dir) {
-	CSPList list(128);
+	CSPList list;
 
 	if (!list.Load(dir, "courses.lst")) {
 		Message("could not load courses.lst");
 		return false;
 	}
 
-	CSPList paramlist(48);
+	CSPList paramlist;
 
 	courses.resize(list.size());
-	size_t i = 0;
+	std::size_t i = 0;
 	for (CSPList::const_iterator line1 = list.cbegin(); line1 != list.cend(); ++line1, i++) {
 		courses[i].name = SPStrN(*line1, "name");
 		courses[i].dir = SPStrN(*line1, "dir", "nodir");
 
-		string coursepath = dir + SEP + courses[i].dir;
+		std::string coursepath = MakePathStr(dir, courses[i].dir);
 		if (DirExists(coursepath.c_str())) {
 			// preview
-			string previewfile = coursepath + SEP "preview.png";
+			std::string previewfile = coursepath + SEP "preview.png";
 			courses[i].preview = new TTexture();
 			if (!courses[i].preview->Load(previewfile, false)) {
 				Message("couldn't load previewfile");
 			}
 
 			// params
-			string paramfile = coursepath + SEP "course.dim";
+			std::string paramfile = coursepath + SEP "course.dim";
 			if (!paramlist.Load(paramfile)) {
 				Message("could not load course.dim");
 			}
 
-			const string& line2 = paramlist.front();
-			courses[i].author = SPStrN(line2, "author", "unknown");
+			const std::string& line2 = paramlist.front();
+			courses[i].author = SPStrN(line2, "author", Trans.Text(109));
 			courses[i].size.x = SPFloatN(line2, "width", 100);
 			courses[i].size.y = SPFloatN(line2, "length", 1000);
 			courses[i].play_size.x = SPFloatN(line2, "play_width", 90);
@@ -708,19 +686,19 @@ bool CCourseList::Load(const std::string& dir) {
 }
 
 void CCourseList::Free() {
-	for (size_t i = 0; i < courses.size(); i++) {
+	for (std::size_t i = 0; i < courses.size(); i++) {
 		delete courses[i].preview;
 	}
 	courses.clear();
 }
 
 void CCourse::FreeCourseList() {
-	for (std::map<std::string, CCourseList>::iterator i = CourseLists.begin(); i != CourseLists.end(); ++i)
+	for (std::unordered_map<std::string, CCourseList>::iterator i = CourseLists.begin(); i != CourseLists.end(); ++i)
 		i->second.Free();
 }
 
 bool CCourse::LoadCourseList() {
-	CSPList list(128);
+	CSPList list;
 
 	if (!list.Load(param.common_course_dir, "groups.lst")) {
 		Message("could not load groups.lst");
@@ -736,8 +714,8 @@ bool CCourse::LoadCourseList() {
 	return true;
 }
 
-CCourseList* CCourse::getGroup(size_t index) {
-	std::map<std::string, CCourseList>::iterator i = CourseLists.begin();
+CCourseList* CCourse::getGroup(std::size_t index) {
+	std::unordered_map<std::string, CCourseList>::iterator i = CourseLists.begin();
 	std::advance(i, index);
 	return &i->second;
 }
@@ -785,7 +763,7 @@ bool CCourse::LoadCourse(TCourse* course) {
 		}
 
 		// ................................................................
-		string itemfile = CourseDir + SEP "items.lst";
+		std::string itemfile = CourseDir + SEP "items.lst";
 		bool itemsexists = FileExists(itemfile);
 		const CControl *ctrl = g_game.player->ctrl;
 
@@ -812,7 +790,7 @@ bool CCourse::LoadCourse(TCourse* course) {
 	return true;
 }
 
-size_t CCourse::GetEnv() const {
+std::size_t CCourse::GetEnv() const {
 	return curr_course->env;
 }
 
@@ -829,22 +807,22 @@ void CCourse::MirrorCourseData() {
 
 			int idx1 = (x+1) + nx*(y);
 			int idx2 = (nx-1-x) + nx*(y);
-			swap(Fields[idx1].terrain, Fields[idx2].terrain);
+			std::swap(Fields[idx1].terrain, Fields[idx2].terrain);
 
 			idx1 = (x) + nx*(y);
 			idx2 = (nx-1-x) + nx*(y);
-			swap(Fields[idx1].nml, Fields[idx2].nml);
+			std::swap(Fields[idx1].nml, Fields[idx2].nml);
 			Fields[idx1].nml.x *= -1;
 			Fields[idx2].nml.x *= -1;
 		}
 	}
 
-	for (size_t i=0; i<CollArr.size(); i++) {
+	for (std::size_t i=0; i<CollArr.size(); i++) {
 		CollArr[i].pt.x = curr_course->size.x - CollArr[i].pt.x;
 		CollArr[i].pt.y = FindYCoord(CollArr[i].pt.x, CollArr[i].pt.z);
 	}
 
-	for (size_t i=0; i<NocollArr.size(); i++) {
+	for (std::size_t i=0; i<NocollArr.size(); i++) {
 		NocollArr[i].pt.x = curr_course->size.x - NocollArr[i].pt.x;
 		NocollArr[i].pt.y = FindYCoord(NocollArr[i].pt.x, NocollArr[i].pt.z);
 	}
@@ -881,10 +859,10 @@ void CCourse::GetIndicesForPoint(double x, double z, unsigned int* x0, unsigned
 	if (yidx < 0) yidx = 0;
 	else if (yidx > ny-1) yidx = ny-1;
 
-	*x0 = (unsigned int)(xidx);              // floor(xidx)
-	*x1 = (unsigned int)(xidx + 0.9999);     // ceil(xidx)
-	*y0 = (unsigned int)(yidx);              // floor(yidx)
-	*y1 = (unsigned int)(yidx + 0.9999);     // ceil(yidx)
+	*x0 = (unsigned int)std::floor(xidx);
+	*x1 = (unsigned int)std::ceil(xidx);
+	*y0 = (unsigned int)std::floor(yidx);
+	*y1 = (unsigned int)std::ceil(yidx);
 
 	if (*x0 == *x1) {
 		if (*x1 < nx - 1)(*x1)++;
@@ -964,8 +942,8 @@ TVector3d CCourse::FindCourseNormal(double x, double z) const {
 	TVector3d tri_nml = CrossProduct(p1 - p0, p2 - p0);
 	tri_nml.Norm();
 
-	double min_bary = min(u, min(v, 1. - u - v));
-	double interp_factor = min(min_bary / NORM_INTERPOL, 1.0);
+	double min_bary = std::min(u, std::min(v, 1. - u - v));
+	double interp_factor = std::min(min_bary / NORM_INTERPOL, 1.0);
 
 	TVector3d interp_nml = interp_factor * tri_nml + (1.-interp_factor) * smooth_nml;
 	interp_nml.Norm();
@@ -1002,7 +980,7 @@ void CCourse::GetSurfaceType(double x, double z, double weights[]) const {
 	double u, v;
 	FindBarycentricCoords(x, z, &idx0, &idx1, &idx2, &u, &v);
 
-	for (size_t i=0; i<Course.TerrList.size(); i++) {
+	for (std::size_t i=0; i<Course.TerrList.size(); i++) {
 		weights[i] = 0;
 		if (Course.Fields[idx0.x + nx*idx0.y].terrain == i) weights[i] += u;
 		if (Course.Fields[idx1.x + nx*idx1.y].terrain == i) weights[i] += v;
@@ -1015,7 +993,7 @@ int CCourse::GetTerrainIdx(double x, double z, double level) const {
 	double u, v;
 	FindBarycentricCoords(x, z, &idx0, &idx1, &idx2, &u, &v);
 
-	for (size_t i=0; i<Course.TerrList.size(); i++) {
+	for (std::size_t i=0; i<Course.TerrList.size(); i++) {
 		double wheight = 0.0;
 		if (Course.Fields[idx0.x + nx*idx0.y].terrain == i) wheight += u;
 		if (Course.Fields[idx1.x + nx*idx1.y].terrain == i) wheight += v;
