@@ -21,10 +21,8 @@ GNU General Public License for more details.
 #include "states.h"
 #include <forward_list>
 
-#define MAX_CREDITS 64
-
 struct TCredits {
-	string text;
+	std::string text;
 	float size;
 	int offs;
 	int font;
@@ -32,7 +30,7 @@ struct TCredits {
 };
 
 class CCredits : public State {
-	forward_list<TCredits> CreditList;
+	std::forward_list<TCredits> CreditList;
 
 	void DrawCreditsText(float time_step);
 	void Enter();
