@@ -29,7 +29,7 @@ GNU General Public License for more details.
 
 #define CURSOR_SIZE 10
 
-static vector<TWidget*> Widgets;
+static std::vector<TWidget*> Widgets;
 static int lock_focussed = -1;
 static int focussed = -1;
 static bool locked_LR = false;
@@ -83,15 +83,19 @@ TLabel::TLabel(const sf::String& string, int x, int y, const sf::Color& color)
 		text.setPosition((Winsys.resolution.width - text.getLocalBounds().width) / 2, y);
 	else
 		text.setPosition(x, y);
-	text.setColor(color);
+	text.setFillColor(color);
+	text.setOutlineColor(color);
 }
 
 void TLabel::Focussed(bool masterFocus) {
 	focus = masterFocus && active;
-	if (focus)
-		text.setColor(colDYell);
-	else
-		text.setColor(colWhite);
+	if (focus) {
+		text.setFillColor(colDYell);
+		text.setOutlineColor(colDYell);
+	} else {
+		text.setFillColor(colWhite);
+		text.setOutlineColor(colWhite);
+	}
 }
 
 void TLabel::Draw() const {
@@ -108,16 +112,19 @@ TLabel* AddLabel(const sf::String& string, int x, int y, const sf::Color& color)
 }
 
 
-TFramedText::TFramedText(int x, int y, int width, int height, int line, const sf::Color& backcol, const sf::String& string, float ftsize, bool borderFocus_)
+TFramedText::TFramedText(int x, int y, int width, int height, int line, const sf::Color& backcol, const sf::String& string, unsigned int ftsize, bool borderFocus_)
 	: TWidget(x, y, width, height, false)
 	, frame(sf::Vector2f(width - line * 2, height - line * 2))
 	, text(string, FT.getCurrentFont(), ftsize)
 	, borderFocus(borderFocus_) {
 	text.setPosition(x + line + 20, y + line);
-	if (!borderFocus)
-		text.setColor(colWhite);
-	else
-		text.setColor(colDYell);
+	if (!borderFocus) {
+		text.setFillColor(colWhite);
+		text.setOutlineColor(colWhite);
+	} else {
+		text.setFillColor(colDYell);
+		text.setOutlineColor(colDYell);
+	}
 	frame.setPosition(x + line, y + line);
 	frame.setOutlineThickness(line);
 	frame.setFillColor(backcol);
@@ -125,24 +132,32 @@ TFramedText::TFramedText(int x, int y, int width, int height, int line, const sf
 }
 
 void TFramedText::Activated() {
-	if (!active)
-		text.setColor(colLGrey);
-	else if (borderFocus || focus)
-		text.setColor(colDYell);
-	else
-		text.setColor(colWhite);
+	if (!active) {
+		text.setFillColor(colLGrey);
+		text.setOutlineColor(colLGrey);
+	} else if (borderFocus || focus) {
+		text.setFillColor(colDYell);
+		text.setOutlineColor(colDYell);
+	} else {
+		text.setFillColor(colWhite);
+		text.setOutlineColor(colWhite);
+	}
 }
 
 void TFramedText::Focussed(bool masterFocus) {
 	focus = masterFocus && active;
 	if (focus) {
 		frame.setOutlineColor(colDYell);
-		if (!borderFocus)
-			text.setColor(colDYell);
+		if (!borderFocus) {
+			text.setFillColor(colDYell);
+			text.setOutlineColor(colDYell);
+		}
 	} else {
 		frame.setOutlineColor(colWhite);
-		if (!borderFocus)
-			text.setColor(colWhite);
+		if (!borderFocus) {
+			text.setFillColor(colWhite);
+			text.setOutlineColor(colWhite);
+		}
 	}
 }
 
@@ -151,19 +166,19 @@ void TFramedText::Draw() const {
 	Winsys.draw(text);
 }
 
-TFramedText* AddFramedText(int x, int y, int width, int height, int line, const sf::Color& backcol, const sf::String& text, float ftsize, bool borderFocus) {
+TFramedText* AddFramedText(int x, int y, int width, int height, int line, const sf::Color& backcol, const sf::String& text, unsigned int ftsize, bool borderFocus) {
 	return static_cast<TFramedText*>(AddWidget(new TFramedText(x, y, width, height, line, backcol, text, ftsize, borderFocus)));
 }
 
-TTextButton::TTextButton(int x, int y, const sf::String& text_, float ftsize)
+TTextButton::TTextButton(int x, int y, const sf::String& text_, int ftsize)
 	: TWidget(x, y, 0, 0)
 	, text(text_, FT.getCurrentFont(), ftsize) {
 	if (ftsize < 0) text.setCharacterSize(FT.AutoSizeN(4));
 
-	float len = text.getLocalBounds().width;
-	if (x == CENTER) position.x = (int)((Winsys.resolution.width - len) / 2);
+	int len = text.getLocalBounds().width;
+	if (x == CENTER) position.x = (Winsys.resolution.width - len) / 2;
 	text.setPosition(position.x, position.y);
-	int offs = (int)(ftsize / 5);
+	int offs = ftsize / 5;
 	mouseRect.left = position.x-20;
 	mouseRect.top = position.y+offs;
 	mouseRect.width = len+40;
@@ -171,22 +186,25 @@ TTextButton::TTextButton(int x, int y, const sf::String& text_, float ftsize)
 }
 
 void TTextButton::Focussed() {
-	if (focus)
-		text.setColor(colDYell);
-	else
-		text.setColor(colWhite);
+	if (focus) {
+		text.setFillColor(colDYell);
+		text.setOutlineColor(colDYell);
+	} else {
+		text.setFillColor(colWhite);
+		text.setOutlineColor(colWhite);
+	}
 }
 
 void TTextButton::Draw() const {
 	Winsys.draw(text);
 }
 
-TTextButton* AddTextButton(const sf::String& text, int x, int y, float ftsize) {
+TTextButton* AddTextButton(const sf::String& text, int x, int y, int ftsize) {
 	return static_cast<TTextButton*>(AddWidget(new TTextButton(x, y, text, ftsize)));
 }
 
 TTextButton* AddTextButtonN(const sf::String& text, int x, int y, int rel_ftsize) {
-	double siz = FT.AutoSizeN(rel_ftsize);
+	unsigned int siz = FT.AutoSizeN(rel_ftsize);
 	return AddTextButton(text, x, y, siz);
 }
 
@@ -195,7 +213,7 @@ TTextField::TTextField(int x, int y, int width, int height, const sf::String& te
 	: TWidget(x, y, width, height)
 	, text(text_, FT.getCurrentFont(), FT.AutoSizeN(5))
 	, frame(sf::Vector2f(width-6.f, height-6.f))
-	, cursorShape(sf::Vector2f(2.f, 26.f * Winsys.scale))
+	, cursorShape(sf::Vector2f(2.f, 30.f * Winsys.scale))
 	, maxLng(32)
 	, time(0.0)
 	, cursor(false) {
@@ -215,41 +233,50 @@ void TTextField::Draw() const {
 		Winsys.draw(cursorShape);
 }
 
-void TTextField::TextEnter(char key) {
-	if (key != '\b') {
+void TTextField::TextEnter(char c) {
+	if (c != '\b') {
 		sf::String string = text.getString();
-		string.insert(cursorPos, key);
+		string.insert(cursorPos, c);
 		text.setString(string);
 		SetCursorPos(cursorPos+1);
 	}
 }
 
-void TTextField::SetCursorPos(size_t new_pos) {
+void TTextField::SetCursorPos(std::size_t new_pos) {
 	cursorPos = new_pos;
-
-	int x = mouseRect.left + 20 - 2;
-	if (cursorPos != 0) {
-		// substring() is very new addition to SFML2 string class, so
-		// for compatibility with older version we use std::string to do it.
-                string temp = text.getString();
-		FT.AutoSizeN(5);
-		x += FT.GetTextWidth(temp.substr(0, cursorPos));
-	}
-
-	cursorShape.setPosition(x, mouseRect.top + 9);
+	cursorShape.setPosition(text.findCharacterPos(cursorPos).x, mouseRect.top + 9);
 }
 
 void TTextField::Focussed() {
 	if (focus) {
-		text.setColor(colDYell);
+		text.setFillColor(colDYell);
+		text.setOutlineColor(colDYell);
 		frame.setOutlineColor(colDYell);
 	} else {
-		text.setColor(colWhite);
+		text.setFillColor(colWhite);
+		text.setOutlineColor(colWhite);
 		frame.setOutlineColor(colWhite);
 	}
 }
 
-static void eraseFromText(sf::Text& text, size_t pos) {
+bool TTextField::Click(int x, int y) {
+	if (TWidget::Click(x, y)) {
+		cursorPos = 0;
+		float first = text.findCharacterPos(cursorPos).x;
+		for (;;) {
+			float second = text.findCharacterPos(cursorPos + 1).x;
+			if ((first + second) / 2.f >= x || cursorPos >= text.getString().getSize())
+				break;
+			cursorPos++;
+			first = second;
+		}
+		cursorShape.setPosition(text.findCharacterPos(cursorPos).x, mouseRect.top + 9);
+		return true;
+	}
+	return false;
+}
+
+static void eraseFromText(sf::Text& text, std::size_t pos) {
 	sf::String str = text.getString();
 	str.erase(pos, 1);
 	text.setString(str);
@@ -274,6 +301,8 @@ void TTextField::Key(sf::Keyboard::Key key, bool released) {
 		case sf::Keyboard::End:
 			SetCursorPos(text.getString().getSize());
 			break;
+		default:
+			break;
 	}
 }
 
@@ -311,10 +340,13 @@ void TCheckbox::SetPosition(int x, int y) {
 }
 
 void TCheckbox::Focussed() {
-	if (focus)
-		text.setColor(colDYell);
-	else
-		text.setColor(colWhite);
+	if (focus) {
+		text.setFillColor(colDYell);
+		text.setOutlineColor(colDYell);
+	} else {
+		text.setFillColor(colWhite);
+		text.setOutlineColor(colWhite);
+	}
 }
 
 void TCheckbox::Draw() const {
@@ -344,14 +376,14 @@ TCheckbox* AddCheckbox(int x, int y, int width, const sf::String& tag) {
 	return static_cast<TCheckbox*>(AddWidget(new TCheckbox(x, y, width, tag)));
 }
 
-TIconButton::TIconButton(int x, int y, const sf::Texture& texture, double size_, int max_, int value_)
+TIconButton::TIconButton(int x, int y, const sf::Texture& texture, float size_, int max_, int value_)
 	: TWidget(x, y, 32, 32)
 	, sprite(texture)
 	, frame(sf::Vector2f(size_, size_))
 	, size(size_)
 	, maximum(max_)
 	, value(value_) {
-	sprite.setScale(size / (texture.getSize().x / 2.0), size / (texture.getSize().y / 2.0));
+	sprite.setScale(size / (texture.getSize().x / 2.f), size / (texture.getSize().y / 2.f));
 	sprite.setPosition(x, y);
 	frame.setPosition(x, y);
 	frame.setOutlineColor(colWhite);
@@ -369,16 +401,16 @@ void TIconButton::SetValue(int _value) {
 	sf::Vector2u texSize = sprite.getTexture()->getSize();
 	switch (value) {
 		case 0:
-			sprite.setTextureRect(sf::IntRect(0, 0, texSize.x / 2.0, texSize.y / 2.0));
+			sprite.setTextureRect(sf::IntRect(0, 0, texSize.x / 2, texSize.y / 2));
 			break;
 		case 1:
-			sprite.setTextureRect(sf::IntRect(texSize.x / 2.0, 0, texSize.x / 2.0, texSize.y / 2.0));
+			sprite.setTextureRect(sf::IntRect(texSize.x / 2, 0, texSize.x / 2, texSize.y / 2));
 			break;
 		case 2:
-			sprite.setTextureRect(sf::IntRect(0, texSize.y / 2.0, texSize.x / 2.0, texSize.y / 2.0));
+			sprite.setTextureRect(sf::IntRect(0, texSize.y / 2, texSize.x / 2, texSize.y / 2));
 			break;
 		case 3:
-			sprite.setTextureRect(sf::IntRect(texSize.x / 2.0, texSize.y / 2.0, texSize.x / 2.0, texSize.y / 2.0));
+			sprite.setTextureRect(sf::IntRect(texSize.x / 2, texSize.y / 2, texSize.x / 2, texSize.y / 2));
 			break;
 	}
 }
@@ -413,7 +445,7 @@ void TIconButton::Key(sf::Keyboard::Key key, bool released) {
 	}
 }
 
-TIconButton* AddIconButton(int x, int y, const sf::Texture& texture, double size, int maximum, int value) {
+TIconButton* AddIconButton(int x, int y, const sf::Texture& texture, float size, int maximum, int value) {
 	locked_UD = true;
 	return static_cast<TIconButton*>(AddWidget(new TIconButton(x, y, texture, size, maximum, value)));
 }
@@ -437,8 +469,8 @@ void TArrow::Activated() {
 }
 
 void TArrow::SetTexture() {
-	static const float textl[6] = { 0.5, 0.0, 0.5, 0.5, 0.0, 0.5 };
-	static const float texbr[6] = { 0.50, 0.50, 0.00, 0.75, 0.75, 0.25 };
+	static const float textl[6] = { 0.5f, 0.f, 0.5f, 0.5f, 0.f, 0.5f };
+	static const float texbr[6] = { 0.5f, 0.5f, 0.f, 0.75f, 0.75f, 0.25f };
 
 	int type = 0;
 	if (active)
@@ -449,7 +481,7 @@ void TArrow::SetTexture() {
 		type += 3;
 
 	sf::Vector2u texSize = sprite.getTexture()->getSize();
-	sprite.setTextureRect(sf::IntRect(textl[type] * texSize.x, texbr[type] * texSize.y, 0.5 * texSize.x, 0.25 * texSize.y));
+	sprite.setTextureRect(sf::IntRect(textl[type] * texSize.x, texbr[type] * texSize.y, texSize.x / 2, texSize.y / 4));
 }
 
 void TArrow::Draw() const {
@@ -461,15 +493,18 @@ TArrow* AddArrow(int x, int y, bool down) {
 }
 
 
-TUpDown::TUpDown(int x, int y, int min_, int max_, int value_, int distance)
+TUpDown::TUpDown(int x, int y, int min_, int max_, int value_, int distance, bool swapArrows_)
 	: TWidget(x, y, 32 * Winsys.scale / 0.8f, (32 + distance)*Winsys.scale / 0.8f)
 	, up(x, y + (16 + distance)*Winsys.scale / 0.8f, true)
 	, down(x, y, false)
+	, higher(swapArrows_ ? up : down)
+	, lower(swapArrows_ ? down : up)
 	, value(value_)
 	, minimum(min_)
-	, maximum(max_) {
-	up.SetActive(value < maximum);
-	down.SetActive(value > minimum);
+	, maximum(max_)
+	, swapArrows(swapArrows_) {
+	lower.SetActive(value < maximum);
+	higher.SetActive(value > minimum);
 }
 
 void TUpDown::Draw() const {
@@ -478,15 +513,15 @@ void TUpDown::Draw() const {
 }
 
 bool TUpDown::Click(int x, int y) {
-	if (active && visible && up.Click(x, y)) {
+	if (active && visible && lower.Click(x, y)) {
 		value++;
-		down.SetActive(true);
+		higher.SetActive(true);
 		if (value == maximum)
-			up.SetActive(false);
+			lower.SetActive(false);
 		return true;
 	}
-	if (active && visible && down.Click(x, y)) {
-		up.SetActive(true);
+	if (active && visible && higher.Click(x, y)) {
+		lower.SetActive(true);
 		value--;
 		if (value == minimum)
 			down.SetActive(false);
@@ -498,19 +533,19 @@ bool TUpDown::Click(int x, int y) {
 void TUpDown::Key(sf::Keyboard::Key key, bool released) {
 	if (released) return;
 
-	if (key == sf::Keyboard::Up) { // Arrow up
+	if ((!swapArrows && key == sf::Keyboard::Up) || (swapArrows && key == sf::Keyboard::Down)) { // Arrow up
 		if (value > minimum) {
 			value--;
-			up.SetActive(true);
+			lower.SetActive(true);
 			if (value == minimum)
-				down.SetActive(false);
+				higher.SetActive(false);
 		}
-	} else if (key == sf::Keyboard::Down) { // Arrow down
+	} else if ((!swapArrows && key == sf::Keyboard::Down) || (swapArrows && key == sf::Keyboard::Up)) { // Arrow down
 		if (value < maximum) {
 			value++;
-			down.SetActive(true);
+			higher.SetActive(true);
 			if (value == maximum)
-				up.SetActive(false);
+				lower.SetActive(false);
 		}
 	}
 }
@@ -526,30 +561,30 @@ void TUpDown::MouseMove(int x, int y) {
 
 void TUpDown::SetValue(int value_) {
 	value = clamp(minimum, value_, maximum);
-	up.SetActive(value < maximum);
-	down.SetActive(value > minimum);
+	lower.SetActive(value < maximum);
+	higher.SetActive(value > minimum);
 }
 void TUpDown::SetMinimum(int min_) {
 	minimum = min_;
 	value = clamp(minimum, value, maximum);
-	up.SetActive(value < maximum);
-	down.SetActive(value > minimum);
+	lower.SetActive(value < maximum);
+	higher.SetActive(value > minimum);
 }
 void TUpDown::SetMaximum(int max_) {
 	maximum = max_;
 	value = clamp(minimum, value, maximum);
-	up.SetActive(value < maximum);
-	down.SetActive(value > minimum);
+	lower.SetActive(value < maximum);
+	higher.SetActive(value > minimum);
 }
 
-TUpDown* AddUpDown(int x, int y, int minimum, int maximum, int value, int distance) {
+TUpDown* AddUpDown(int x, int y, int minimum, int maximum, int value, int distance, bool swapArrows) {
 	locked_UD = true;
-	return static_cast<TUpDown*>(AddWidget(new TUpDown(x, y, minimum, maximum, value, distance)));
+	return static_cast<TUpDown*>(AddWidget(new TUpDown(x, y, minimum, maximum, value, distance, swapArrows)));
 }
 
 // ------------------ Elementary drawing ---------------------------------------------
 
-void DrawFrameX(int x, int y, int w, int h, int line, const sf::Color& backcol, const sf::Color& framecol, double transp) {
+void DrawFrameX(int x, int y, int w, int h, int line, const sf::Color& backcol, const sf::Color& framecol, float transp) {
 	x += line;
 	y += line;
 	w -= line * 2;
@@ -562,8 +597,8 @@ void DrawFrameX(int x, int y, int w, int h, int line, const sf::Color& backcol,
 	Winsys.draw(shape);
 }
 
-void DrawBonusExt(int y, size_t numraces, size_t num) {
-	size_t maxtux = numraces * 3;
+void DrawBonusExt(int y, std::size_t numraces, std::size_t num) {
+	std::size_t maxtux = numraces * 3;
 	if (num > maxtux) return;
 
 	static const sf::Color col2(115, 166, 217);
@@ -583,11 +618,11 @@ void DrawBonusExt(int y, size_t numraces, size_t num) {
 
 	static sf::Sprite tuxbonus(Tex.GetSFTexture(TUXBONUS));
 	sf::Vector2u size = tuxbonus.getTexture()->getSize();
-	tuxbonus.setTextureRect(sf::IntRect(0, 0, size.x, 0.5*size.y));
+	tuxbonus.setTextureRect(sf::IntRect(0, 0, size.x, size.y/2));
 
-	for (size_t i=0; i<maxtux; i++) {
-		size_t majr = (i/numraces);
-		size_t minr = i - majr * numraces;
+	for (std::size_t i=0; i<maxtux; i++) {
+		std::size_t majr = (i/numraces);
+		std::size_t minr = i - majr * numraces;
 		if (majr > 2) majr = 2;
 		int x = lleft[majr] + (int)minr * 40 + 6;
 
@@ -604,9 +639,9 @@ void DrawGUIFrame() {
 	static sf::Sprite top_left(Tex.GetSFTexture(TOP_LEFT));
 	static sf::Sprite top_right(Tex.GetSFTexture(TOP_RIGHT));
 
-	bottom_left.setPosition(0, Winsys.resolution.height - 256);
-	bottom_right.setPosition(Winsys.resolution.width - 256, Winsys.resolution.height - 256);
-	top_right.setPosition(Winsys.resolution.width - 256, 0);
+	bottom_left.setPosition(0, Winsys.resolution.height - bottom_left.getTexture()->getSize().y);
+	bottom_right.setPosition(Winsys.resolution.width - bottom_right.getTexture()->getSize().x, Winsys.resolution.height - bottom_right.getTexture()->getSize().y);
+	top_right.setPosition(Winsys.resolution.width - top_right.getTexture()->getSize().x, 0);
 
 	Winsys.draw(bottom_left);
 	Winsys.draw(bottom_right);
@@ -614,13 +649,13 @@ void DrawGUIFrame() {
 	Winsys.draw(top_right);
 }
 
-void DrawGUIBackground(float logoScale) {
+void DrawGUIBackground(float scale) {
 	DrawGUIFrame();
 
 	static sf::Sprite logo(Tex.GetSFTexture(T_TITLE));
-	logoScale *= 0.5f;
-	logo.setScale(logoScale, logoScale);
-	logo.setPosition((Winsys.resolution.width - logo.getTextureRect().width*logoScale)/2, 5);
+	scale *= 0.5f;
+	logo.setScale(scale, scale);
+	logo.setPosition((Winsys.resolution.width - logo.getTextureRect().width*scale)/2, 5);
 	Winsys.draw(logo);
 }
 
@@ -639,7 +674,7 @@ void DrawCursor() {
 // ------------------ Main GUI functions ---------------------------------------------
 
 void DrawGUI() {
-	for (size_t i = 0; i < Widgets.size(); i++)
+	for (std::size_t i = 0; i < Widgets.size(); i++)
 		if (Widgets[i]->GetVisible())
 			Widgets[i]->Draw();
 	if (param.ice_cursor)
@@ -648,7 +683,7 @@ void DrawGUI() {
 
 TWidget* ClickGUI(int x, int y) {
 	TWidget* clicked = nullptr;
-	for (size_t i = 0; i < Widgets.size(); i++) {
+	for (std::size_t i = 0; i < Widgets.size(); i++) {
 		if (Widgets[i]->Click(x, y)) {
 			clicked = Widgets[i];
 			lock_focussed = focussed;
@@ -660,7 +695,7 @@ TWidget* ClickGUI(int x, int y) {
 TWidget* MouseMoveGUI(int x, int y) {
 	if (x != 0 || y != 0) {
 		focussed = -1;
-		for (size_t i = 0; i < Widgets.size(); i++) {
+		for (std::size_t i = 0; i < Widgets.size(); i++) {
 			Widgets[i]->MouseMove(cursor_pos.x, cursor_pos.y);
 			if (Widgets[i]->focussed())
 				focussed = (int)i;
@@ -724,7 +759,7 @@ void SetFocus(TWidget* widget) {
 	if (!widget)
 		focussed = -1;
 	else
-		for (size_t i = 0; i < Widgets.size(); i++) {
+		for (std::size_t i = 0; i < Widgets.size(); i++) {
 			if (Widgets[i] == widget) {
 				Widgets[i]->focus = true;
 				Widgets[i]->Focussed();
@@ -793,7 +828,7 @@ void DecreaseFocus() {
 }
 
 void ResetGUI() {
-	for (size_t i = 0; i < Widgets.size(); i++)
+	for (std::size_t i = 0; i < Widgets.size(); i++)
 		delete Widgets[i];
 	Widgets.clear();
 	focussed = 0;
