@@ -62,10 +62,10 @@ void InitGame(int argc, char **argv) {
 }
 
 int main(int argc, char **argv) {
-	cout << "\n----------- Extreme Tux Racer " ETR_VERSION_STRING " ----------------";
-	cout << "\n----------- (C) 2010-2018 Extreme Tuxracer Team  --------\n\n";
+	std::cout << "\n----------- Extreme Tux Racer " ETR_VERSION_STRING " ----------------";
+	std::cout << "\n----------- (C) 2010-2020 Extreme Tuxracer Team  --------\n\n";
 
-	srand(time(nullptr));
+	std::srand(std::time(nullptr));
 	InitConfig();
 	InitGame(argc, argv);
 	Winsys.Init();
