@@ -48,8 +48,8 @@ static const sf::Color shad_col(0, 0, 0, 76);
 static const sf::Color shad_col(0, 0, 0, 25);
 #endif
 
-static const TCharMaterial TuxDefMat = { sf::Color(0.5 * 255, 0.5 * 255, 0.5 * 255), colBlack, 0.0 };
-static const TCharMaterial Highlight = { sf::Color(0.8 * 255, 0.15 * 255, 0.15 * 255), colBlack, 0.0 };
+static const TCharMaterial TuxDefMat = { sf::Color(128, 128, 128), colBlack, 0.0 };
+static const TCharMaterial Highlight = { sf::Color(204, 38, 38), colBlack, 0.0 };
 CCharShape TestChar;
 
 CCharShape::CCharShape() {
@@ -80,13 +80,13 @@ CCharShape::~CCharShape() {
 //				nodes
 // --------------------------------------------------------------------
 
-size_t CCharShape::GetNodeIdx(size_t node_name) const {
+std::size_t CCharShape::GetNodeIdx(std::size_t node_name) const {
 	if (node_name >= MAX_CHAR_NODES) return -1;
 	return Index[node_name];
 }
 
-TCharNode *CCharShape::GetNode(size_t node_name) {
-	size_t idx = GetNodeIdx(node_name);
+TCharNode *CCharShape::GetNode(std::size_t node_name) const {
+	std::size_t idx = GetNodeIdx(node_name);
 	if (idx >= numNodes) return nullptr;
 	return Nodes[idx];
 }
@@ -115,7 +115,7 @@ void CCharShape::CreateRootNode() {
 	numNodes = 1;
 }
 
-bool CCharShape::CreateCharNode(int parent_name, size_t node_name, const string& joint, const string& name, const string& order, bool shadow) {
+bool CCharShape::CreateCharNode(int parent_name, std::size_t node_name, const std::string& joint, const std::string& name, const std::string& order, bool shadow) {
 	TCharNode *parent = GetNode(parent_name);
 	if (parent == nullptr) {
 		Message("wrong parent node");
@@ -167,8 +167,8 @@ bool CCharShape::CreateCharNode(int parent_name, size_t node_name, const string&
 	return true;
 }
 
-void CCharShape::AddAction(size_t node_name, int type, const TVector3d& vec, double val) {
-	size_t idx = GetNodeIdx(node_name);
+void CCharShape::AddAction(std::size_t node_name, int type, const TVector3d& vec, double val) {
+	std::size_t idx = GetNodeIdx(node_name);
 	TCharAction *act = Nodes[idx]->action;
 	act->type[act->num] = type;
 	act->vec[act->num] = vec;
@@ -176,7 +176,7 @@ void CCharShape::AddAction(size_t node_name, int type, const TVector3d& vec, dou
 	act->num++;
 }
 
-bool CCharShape::TranslateNode(size_t node_name, const TVector3d& vec) {
+bool CCharShape::TranslateNode(std::size_t node_name, const TVector3d& vec) {
 	TCharNode *node = GetNode(node_name);
 	if (node == nullptr) return false;
 
@@ -191,7 +191,7 @@ bool CCharShape::TranslateNode(size_t node_name, const TVector3d& vec) {
 	return true;
 }
 
-bool CCharShape::RotateNode(size_t node_name, int axis, double angle) {
+bool CCharShape::RotateNode(std::size_t node_name, int axis, double angle) {
 	TCharNode *node = GetNode(node_name);
 	if (node == nullptr) return false;
 
@@ -220,13 +220,13 @@ bool CCharShape::RotateNode(size_t node_name, int axis, double angle) {
 	return true;
 }
 
-bool CCharShape::RotateNode(const string& node_trivialname, int axis, double angle) {
-	map<string, size_t>::const_iterator i = NodeIndex.find(node_trivialname);
+bool CCharShape::RotateNode(const std::string& node_trivialname, int axis, double angle) {
+	std::unordered_map<std::string, std::size_t>::const_iterator i = NodeIndex.find(node_trivialname);
 	if (i == NodeIndex.end()) return false;
 	return RotateNode(i->second, axis, angle);
 }
 
-void CCharShape::ScaleNode(size_t node_name, const TVector3d& vec) {
+void CCharShape::ScaleNode(std::size_t node_name, const TVector3d& vec) {
 	TCharNode *node = GetNode(node_name);
 	if (node == nullptr) return;
 
@@ -240,7 +240,7 @@ void CCharShape::ScaleNode(size_t node_name, const TVector3d& vec) {
 	if (newActions && useActions) AddAction(node_name, 4, vec, 0);
 }
 
-bool CCharShape::VisibleNode(size_t node_name, float level) {
+bool CCharShape::VisibleNode(std::size_t node_name, float level) {
 	TCharNode *node = GetNode(node_name);
 	if (node == nullptr) return false;
 
@@ -248,14 +248,14 @@ bool CCharShape::VisibleNode(size_t node_name, float level) {
 
 	if (node->visible) {
 		node->divisions =
-		    clamp(MIN_SPHERE_DIV, ROUND_TO_NEAREST(param.tux_sphere_divisions * level / 10), MAX_SPHERE_DIV);
+		    clamp(MIN_SPHERE_DIV, (int)std::lround(param.tux_sphere_divisions * level / 10), MAX_SPHERE_DIV);
 		node->radius = 1.0;
 	}
 	if (newActions && useActions) AddAction(node_name, 5, NullVec3, level);
 	return true;
 }
 
-bool CCharShape::MaterialNode(size_t node_name, const string& mat_name) {
+bool CCharShape::MaterialNode(std::size_t node_name, const std::string& mat_name) {
 	TCharNode *node = GetNode(node_name);
 	if (node == nullptr) return false;
 	TCharMaterial *mat = GetMaterial(mat_name);
@@ -265,7 +265,7 @@ bool CCharShape::MaterialNode(size_t node_name, const string& mat_name) {
 	return true;
 }
 
-bool CCharShape::ResetNode(size_t node_name) {
+bool CCharShape::ResetNode(std::size_t node_name) {
 	TCharNode *node = GetNode(node_name);
 	if (node == nullptr) return false;
 
@@ -274,13 +274,13 @@ bool CCharShape::ResetNode(size_t node_name) {
 	return true;
 }
 
-bool CCharShape::ResetNode(const string& node_trivialname) {
-	map<string, size_t>::const_iterator i = NodeIndex.find(node_trivialname);
+bool CCharShape::ResetNode(const std::string& node_trivialname) {
+	std::unordered_map<std::string, std::size_t>::const_iterator i = NodeIndex.find(node_trivialname);
 	if (i == NodeIndex.end()) return false;
 	return ResetNode(i->second);
 }
 
-bool CCharShape::TransformNode(size_t node_name, const TMatrix<4, 4>& mat, const TMatrix<4, 4>& invmat) {
+bool CCharShape::TransformNode(std::size_t node_name, const TMatrix<4, 4>& mat, const TMatrix<4, 4>& invmat) {
 	TCharNode *node = GetNode(node_name);
 	if (node == nullptr) return false;
 
@@ -329,15 +329,15 @@ void CCharShape::Reset() {
 //				materials
 // --------------------------------------------------------------------
 
-TCharMaterial* CCharShape::GetMaterial(const string& mat_name) {
-	map<string, size_t>::const_iterator i = MaterialIndex.find(mat_name);
+TCharMaterial* CCharShape::GetMaterial(const std::string& mat_name) {
+	std::unordered_map<std::string, std::size_t>::const_iterator i = MaterialIndex.find(mat_name);
 	if (i != MaterialIndex.end() && i->second < Materials.size()) {
 		return &Materials[i->second];
 	}
 	return nullptr;
 }
 
-void CCharShape::CreateMaterial(const string& line) {
+void CCharShape::CreateMaterial(const std::string& line) {
 	TVector3d diff = SPVector3d(line, "diff");
 	TVector3d spec = SPVector3d(line, "spec");
 	float exp = SPFloatN(line, "exp", 50);
@@ -363,7 +363,7 @@ void CCharShape::CreateMaterial(const string& line) {
 //				drawing
 // --------------------------------------------------------------------
 
-void CCharShape::DrawCharSphere(int num_divisions) {
+void CCharShape::DrawCharSphere(int num_divisions) const {
 	GLUquadricObj *qobj = gluNewQuadric();
 	gluQuadricDrawStyle(qobj, GLU_FILL);
 	gluQuadricOrientation(qobj, GLU_OUTSIDE);
@@ -408,7 +408,7 @@ void CCharShape::Draw() {
 	ScopedRenderMode rm(TUX);
 	glEnable(GL_NORMALIZE);
 
-	TCharNode *node = GetNode(0);
+	const TCharNode *node = GetNode(0);
 	if (node == nullptr) return;
 
 	DrawNodes(node);
@@ -419,8 +419,8 @@ void CCharShape::Draw() {
 
 // --------------------------------------------------------------------
 
-bool CCharShape::Load(const string& dir, const string& filename, bool with_actions) {
-	CSPList list(500);
+bool CCharShape::Load(const std::string& dir, const std::string& filename, bool with_actions) {
+	CSPList list;
 
 	useActions = with_actions;
 	CreateRootNode();
@@ -434,20 +434,20 @@ bool CCharShape::Load(const string& dir, const string& filename, bool with_actio
 	for (CSPList::const_iterator line = list.cbegin(); line != list.cend(); ++line) {
 		int node_name = SPIntN(*line, "node", -1);
 		int parent_name = SPIntN(*line, "par", -1);
-		string mat_name = SPStrN(*line, "mat");
-		string name = SPStrN(*line, "joint");
-		string fullname = SPStrN(*line, "name");
+		std::string mat_name = SPStrN(*line, "mat");
+		std::string name = SPStrN(*line, "joint");
+		std::string fullname = SPStrN(*line, "name");
 
 		if (SPIntN(*line, "material", 0) > 0) {
 			CreateMaterial(*line);
 		} else {
 			float visible = SPFloatN(*line, "vis", -1.f);
 			bool shadow = SPBoolN(*line, "shad", false);
-			string order = SPStrN(*line, "order");
+			std::string order = SPStrN(*line, "order");
 			CreateCharNode(parent_name, node_name, name, fullname, order, shadow);
 			TVector3d rot = SPVector3d(*line, "rot");
 			MaterialNode(node_name, mat_name);
-			for (size_t ii = 0; ii < order.size(); ii++) {
+			for (std::size_t ii = 0; ii < order.size(); ii++) {
 				int act = order[ii]-48;
 				switch (act) {
 					case 0: {
@@ -485,14 +485,14 @@ bool CCharShape::Load(const string& dir, const string& filename, bool with_actio
 	return true;
 }
 
-TVector3d CCharShape::AdjustRollvector(const CControl *ctrl, const TVector3d& vel_, const TVector3d& zvec) {
+TVector3d CCharShape::AdjustRollvector(const CControl *ctrl, const TVector3d& vel, const TVector3d& zvec) {
 	TMatrix<4, 4> rot_mat;
-	TVector3d vel = ProjectToPlane(zvec, vel_);
-	vel.Norm();
+	TVector3d v = ProjectToPlane(zvec, vel);
+	v.Norm();
 	if (ctrl->is_braking) {
-		rot_mat = RotateAboutVectorMatrix(vel, ctrl->turn_fact * BRAKING_ROLL_ANGLE);
+		rot_mat = RotateAboutVectorMatrix(v, ctrl->turn_fact * BRAKING_ROLL_ANGLE);
 	} else {
-		rot_mat = RotateAboutVectorMatrix(vel, ctrl->turn_fact * MAX_ROLL_ANGLE);
+		rot_mat = RotateAboutVectorMatrix(v, ctrl->turn_fact * MAX_ROLL_ANGLE);
 	}
 	return TransformVector(rot_mat, zvec);
 }
@@ -529,7 +529,7 @@ void CCharShape::AdjustOrientation(CControl *ctrl, double dtime,
 
 	ctrl->corientation = InterpolateQuaternions(
 	                         ctrl->corientation, new_orient,
-	                         min(dtime / time_constant, 1.0));
+	                         std::min(dtime / time_constant, 1.0));
 
 	ctrl->plane_nml = RotateVector(ctrl->corientation, minus_z_vec);
 	ctrl->cdirection = RotateVector(ctrl->corientation, y_vec);
@@ -560,22 +560,22 @@ void CCharShape::AdjustJoints(double turnFact, bool isBraking,
 
 	if (isBraking) braking_angle = MAX_ARM_ANGLE2;
 
-	paddling_angle = MAX_PADDLING_ANGLE2 * sin(paddling_factor * M_PI);
-	ext_paddling_angle = MAX_EXT_PADDLING_ANGLE2 * sin(paddling_factor * M_PI);
-	kick_paddling_angle = MAX_KICK_PADDLING_ANGLE2 * sin(paddling_factor * M_PI * 2.0);
+	paddling_angle = MAX_PADDLING_ANGLE2 * std::sin(paddling_factor * M_PI);
+	ext_paddling_angle = MAX_EXT_PADDLING_ANGLE2 * std::sin(paddling_factor * M_PI);
+	kick_paddling_angle = MAX_KICK_PADDLING_ANGLE2 * std::sin(paddling_factor * M_PI * 2.0);
 
-	turning_angle[0] = max(-turnFact,0.0) * MAX_ARM_ANGLE2;
-	turning_angle[1] = max(turnFact,0.0) * MAX_ARM_ANGLE2;
-	flap_angle = MAX_ARM_ANGLE2 * (0.5 + 0.5 * sin(M_PI * flap_factor * 6 - M_PI / 2));
+	turning_angle[0] = std::max(-turnFact,0.0) * MAX_ARM_ANGLE2;
+	turning_angle[1] = std::max(turnFact,0.0) * MAX_ARM_ANGLE2;
+	flap_angle = MAX_ARM_ANGLE2 * (0.5 + 0.5 * std::sin(M_PI * flap_factor * 6 - M_PI / 2));
 	force_angle = clamp(-20.0, -net_force.z / 300.0, 20.0);
 	turn_leg_angle = turnFact * 10;
 
 	ResetJoints();
 
 	RotateNode("left_shldr", 3,
-	           min(braking_angle + paddling_angle + turning_angle[0], MAX_ARM_ANGLE2) + flap_angle);
+	           std::min(braking_angle + paddling_angle + turning_angle[0], MAX_ARM_ANGLE2) + flap_angle);
 	RotateNode("right_shldr", 3,
-	           min(braking_angle + paddling_angle + turning_angle[1], MAX_ARM_ANGLE2) + flap_angle);
+	           std::min(braking_angle + paddling_angle + turning_angle[1], MAX_ARM_ANGLE2) + flap_angle);
 
 	RotateNode("left_shldr", 2, -ext_paddling_angle);
 	RotateNode("right_shldr", 2, ext_paddling_angle);
@@ -583,11 +583,11 @@ void CCharShape::AdjustJoints(double turnFact, bool isBraking,
 	RotateNode("right_hip", 3, -20 - turn_leg_angle + force_angle);
 
 	RotateNode("left_knee", 3,
-	           -10 + turn_leg_angle - min(35.0, speed) + kick_paddling_angle + force_angle);
+	           -10 + turn_leg_angle - std::min(35.0, speed) + kick_paddling_angle + force_angle);
 	RotateNode("right_knee", 3,
-	           -10 - turn_leg_angle - min(35.0, speed) - kick_paddling_angle + force_angle);
-	RotateNode("left_ankle", 3, -20 + min(50.0, speed));
-	RotateNode("right_ankle", 3, -20 + min(50.0, speed));
+	           -10 - turn_leg_angle - std::min(35.0, speed) - kick_paddling_angle + force_angle);
+	RotateNode("left_ankle", 3, -20 + std::min(50.0, speed));
+	RotateNode("right_ankle", 3, -20 + std::min(50.0, speed));
 	RotateNode("tail", 3, turnFact * 20);
 	RotateNode("neck", 3, -50);
 	RotateNode("head", 3, -30);
@@ -622,7 +622,7 @@ bool CCharShape::CheckPolyhedronCollision(const TCharNode *node, const TMatrix<4
 }
 
 bool CCharShape::CheckCollision(const TPolyhedron& ph) {
-	TCharNode *node = GetNode(0);
+	const TCharNode *node = GetNode(0);
 	if (node == nullptr) return false;
 	const TMatrix<4, 4>& identity = TMatrix<4, 4>::getIdentity();
 	return CheckPolyhedronCollision(node, identity, identity, ph);
@@ -638,7 +638,7 @@ bool CCharShape::Collision(const TVector3d& pos, const TPolyhedron& ph) {
 //				shadow
 // --------------------------------------------------------------------
 
-void CCharShape::DrawShadowVertex(double x, double y, double z, const TMatrix<4, 4>& mat) {
+void CCharShape::DrawShadowVertex(double x, double y, double z, const TMatrix<4, 4>& mat) const {
 	TVector3d pt(x, y, z);
 	pt = TransformPoint(mat, pt);
 	double old_y = pt.y;
@@ -649,7 +649,7 @@ void CCharShape::DrawShadowVertex(double x, double y, double z, const TMatrix<4,
 	glVertex3(pt);
 }
 
-void CCharShape::DrawShadowSphere(const TMatrix<4, 4>& mat) {
+void CCharShape::DrawShadowSphere(const TMatrix<4, 4>& mat) const {
 	double theta, phi, d_theta, d_phi, eps, twopi;
 	double x, y, z;
 	int div = param.tux_shadow_sphere_divisions;
@@ -663,18 +663,18 @@ void CCharShape::DrawShadowSphere(const TMatrix<4, 4>& mat) {
 		double sin_phi, cos_phi;
 		double sin_phi_d_phi, cos_phi_d_phi;
 
-		sin_phi = sin(phi);
-		cos_phi = cos(phi);
-		sin_phi_d_phi = sin(phi + d_phi);
-		cos_phi_d_phi = cos(phi + d_phi);
+		sin_phi = std::sin(phi);
+		cos_phi = std::cos(phi);
+		sin_phi_d_phi = std::sin(phi + d_phi);
+		cos_phi_d_phi = std::cos(phi + d_phi);
 
 		if (phi <= eps) {
 			glBegin(GL_TRIANGLE_FAN);
 			DrawShadowVertex(0., 0., 1., mat);
 
 			for (theta = 0.0; theta + eps < twopi; theta += d_theta) {
-				sin_theta = sin(theta);
-				cos_theta = cos(theta);
+				sin_theta = std::sin(theta);
+				cos_theta = std::cos(theta);
 
 				x = cos_theta * sin_phi_d_phi;
 				y = sin_theta * sin_phi_d_phi;
@@ -690,8 +690,8 @@ void CCharShape::DrawShadowSphere(const TMatrix<4, 4>& mat) {
 			glBegin(GL_TRIANGLE_FAN);
 			DrawShadowVertex(0., 0., -1., mat);
 			for (theta = twopi; theta - eps > 0; theta -= d_theta) {
-				sin_theta = sin(theta);
-				cos_theta = cos(theta);
+				sin_theta = std::sin(theta);
+				cos_theta = std::cos(theta);
 				x = cos_theta * sin_phi;
 				y = sin_theta * sin_phi;
 				z = cos_phi;
@@ -705,8 +705,8 @@ void CCharShape::DrawShadowSphere(const TMatrix<4, 4>& mat) {
 		} else {
 			glBegin(GL_TRIANGLE_STRIP);
 			for (theta = 0.0; theta + eps < twopi; theta += d_theta) {
-				sin_theta = sin(theta);
-				cos_theta = cos(theta);
+				sin_theta = std::sin(theta);
+				cos_theta = std::cos(theta);
 				x = cos_theta * sin_phi;
 				y = sin_theta * sin_phi;
 				z = cos_phi;
@@ -730,7 +730,7 @@ void CCharShape::DrawShadowSphere(const TMatrix<4, 4>& mat) {
 	}
 }
 
-void CCharShape::TraverseDagForShadow(const TCharNode *node, const TMatrix<4, 4>& mat) {
+void CCharShape::TraverseDagForShadow(const TCharNode *node, const TMatrix<4, 4>& mat) const {
 	TMatrix<4, 4> new_matrix = mat * node->trans;
 	if (node->visible && node->render_shadow)
 		DrawShadowSphere(new_matrix);
@@ -742,13 +742,13 @@ void CCharShape::TraverseDagForShadow(const TCharNode *node, const TMatrix<4, 4>
 	}
 }
 
-void CCharShape::DrawShadow() {
+void CCharShape::DrawShadow() const {
 	if (g_game.light_id == 1 || g_game.light_id == 3) return;
 
 	ScopedRenderMode rm(TUX_SHADOW);
 	glColor(shad_col);
 
-	TCharNode *node = GetNode(0);
+	const TCharNode *node = GetNode(0);
 	if (node == nullptr) {
 		Message("couldn't find tux's root node");
 		return;
@@ -760,7 +760,7 @@ void CCharShape::DrawShadow() {
 //				testing and tools
 // --------------------------------------------------------------------
 
-string CCharShape::GetNodeJoint(size_t idx) const {
+std::string CCharShape::GetNodeJoint(std::size_t idx) const {
 	if (idx >= numNodes) return "";
 	TCharNode *node = Nodes[idx];
 	if (node == nullptr) return "";
@@ -768,17 +768,17 @@ string CCharShape::GetNodeJoint(size_t idx) const {
 	else return Int_StrN((int)node->node_name);
 }
 
-size_t CCharShape::GetNodeName(size_t idx) const {
+std::size_t CCharShape::GetNodeName(std::size_t idx) const {
 	if (idx >= numNodes) return -1;
 	return Nodes[idx]->node_name;
 }
 
-size_t CCharShape::GetNodeName(const string& node_trivialname) const {
+std::size_t CCharShape::GetNodeName(const std::string& node_trivialname) const {
 	return NodeIndex.at(node_trivialname);
 }
 
 
-void CCharShape::RefreshNode(size_t idx) {
+void CCharShape::RefreshNode(std::size_t idx) {
 	if (idx >= numNodes) return;
 	TMatrix<4, 4> TempMatrix;
 	char caxis;
@@ -792,7 +792,7 @@ void CCharShape::RefreshNode(size_t idx) {
 	node->trans.SetIdentity();
 	node->invtrans.SetIdentity();
 
-	for (size_t i=0; i<act->num; i++) {
+	for (std::size_t i=0; i<act->num; i++) {
 		int type = act->type[i];
 		const TVector3d& vec = act->vec[i];
 		double dval = act->dval[i];
@@ -843,33 +843,33 @@ void CCharShape::RefreshNode(size_t idx) {
 	}
 }
 
-const string& CCharShape::GetNodeFullname(size_t idx) const {
+const std::string& CCharShape::GetNodeFullname(std::size_t idx) const {
 	if (idx >= numNodes) return emptyString;
 	return Nodes[idx]->action->name;
 }
 
-size_t CCharShape::GetNumActs(size_t idx) const {
+std::size_t CCharShape::GetNumActs(std::size_t idx) const {
 	if (idx >= numNodes) return -1;
 	return Nodes[idx]->action->num;
 }
 
-TCharAction *CCharShape::GetAction(size_t idx) const {
+TCharAction *CCharShape::GetAction(std::size_t idx) const {
 	if (idx >= numNodes) return nullptr;
 	return Nodes[idx]->action;
 }
 
-void CCharShape::PrintAction(size_t idx) const {
+void CCharShape::PrintAction(std::size_t idx) const {
 	if (idx >= numNodes) return;
 	TCharAction *act = Nodes[idx]->action;
 	PrintInt((int)act->num);
-	for (size_t i=0; i<act->num; i++) {
+	for (std::size_t i=0; i<act->num; i++) {
 		PrintInt(act->type[i]);
 		PrintDouble(act->dval[i]);
 		PrintVector(act->vec[i]);
 	}
 }
 
-void CCharShape::PrintNode(size_t idx) const {
+void CCharShape::PrintNode(std::size_t idx) const {
 	TCharNode *node = Nodes[idx];
 	PrintInt("node: ", (int)node->node_name);
 	PrintInt("parent: ", (int)node->parent_name);
@@ -877,32 +877,32 @@ void CCharShape::PrintNode(size_t idx) const {
 	PrintInt("next: ", (int)node->next_name);
 }
 
-void CCharShape::SaveCharNodes(const string& dir, const string& filename) {
-	CSPList list(MAX_CHAR_NODES + 10);
+void CCharShape::SaveCharNodes(const std::string& dir, const std::string& filename) {
+	CSPList list;
 
 	list.Add("# Generated by Tuxracer tools");
 	list.Add();
 	if (!Materials.empty()) {
 		list.Add("# Materials:");
-		for (size_t i=0; i<Materials.size(); i++)
+		for (std::size_t i=0; i<Materials.size(); i++)
 			if (!Materials[i].matline.empty())
 				list.Add(Materials[i].matline);
 		list.Add();
 	}
 
 	list.Add("# Nodes:");
-	for (size_t i=1; i<numNodes; i++) {
+	for (std::size_t i=1; i<numNodes; i++) {
 		TCharNode* node = Nodes[i];
 		TCharAction* act = node->action;
 		if (node->parent_name >= node->node_name) Message("wrong parent index");
-		string line = "*[node] " + Int_StrN((int)node->node_name);
+		std::string line = "*[node] " + Int_StrN((int)node->node_name);
 		line += " [par] " + Int_StrN((int)node->parent_name);
 
 		if (!act->order.empty()) {
 			bool rotflag = false;
 			TVector3d rotation;
 			line += " [order] " + act->order;
-			for (size_t ii=0; ii<act->order.size(); ii++) {
+			for (std::size_t ii=0; ii<act->order.size(); ii++) {
 				int aa = act->order[ii]-48;
 				switch (aa) {
 					case 0:
@@ -942,7 +942,7 @@ void CCharShape::SaveCharNodes(const string& dir, const string& filename) {
 		list.Add(line);
 		if (i<numNodes-3) {
 			if (node->visible && !Nodes[i+1]->visible) list.Add();
-			const string& joint = Nodes[i+2]->joint;
+			const std::string& joint = Nodes[i+2]->joint;
 			if (joint.empty()) list.Add("# " + joint);
 		}
 	}
